@@ -20,6 +20,21 @@ class State(object):
         for k, v in kwargs.items():
             setattr(self, k, v)
 
+    def __contains__(self, k):
+        return hasattr(self, k)
+
+    def __getitem__(self, k):
+        try:
+            return getattr(self, k)
+        except AttributeError:
+            raise KeyError
+
+    def __setitem__(self, k, v):
+        setattr(self, k, v)
+
+    def get(self, k, default=None):
+        return getattr(self, k, default)
+
 
 class Form(object):
 
@@ -80,9 +95,6 @@ class Form(object):
         if obj:
             self.data.update(obj.__dict__)
 
-        assert self.schema or self.validators, \
-                "validators and/or schema required"
-
     def is_error(self, field):
         """
         Checks if individual field has errors.
@@ -127,6 +139,9 @@ class Form(object):
 
         """
 
+        assert self.schema or self.validators, \
+                "validators and/or schema required"
+
         if self.is_validated:
             return not(self.errors)
 
